==> openGion6.9.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR2 (   20 )       DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        VARCHAR2 (    1 )                                       /*  30 重要度       */
 , TITLE        VARCHAR2 (  300 )                                       /*  40 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR2 ( 4000 )                                       /*  50 内容         */
 , DYSTRD       VARCHAR2 (    8 )                   NOT NULL            /*  60 掲載開始日   */
 , DYENDD       VARCHAR2 (    8 )                   NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       VARCHAR2 (  100 )                                       /*  80 掲載部署     */
 , MAND         VARCHAR2 (   50 )                                       /*  90 掲載者       */
 , TEL          VARCHAR2 (   20 )                                       /* 100 電話番号     */
 , MAILAD       VARCHAR2 (  100 )                                       /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        VARCHAR2 (  200 )                                       /* 120 ﾌｧｲﾙ1        */
 , FILE2        VARCHAR2 (  200 )                                       /* 130 ﾌｧｲﾙ2        */
 , FILE3        VARCHAR2 (  200 )                                       /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     VARCHAR2 (  200 )                                       /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          VARCHAR2 (  200 )                                       /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01;


CREATE SEQUENCE GE81S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE81T00 
  BEFORE INSERT ON GE81
  FOR EACH ROW 
  BEGIN 
    SELECT GE81S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      VARCHAR2 (   20 )       DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        VARCHAR2 (    1 )                                       /*  30 重要度       */
 , TITLE        VARCHAR2 (  300 )                                       /*  40 ﾀｲﾄﾙ         */
 , NAIYO        VARCHAR2 ( 4000 )                                       /*  50 内容         */
 , DYSTRD       VARCHAR2 (    8 )                   NOT NULL            /*  60 掲載開始日   */
 , DYENDD       VARCHAR2 (    8 )                   NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       VARCHAR2 (  100 )                                       /*  80 掲載部署     */
 , MAND         VARCHAR2 (   50 )                                       /*  90 掲載者       */
 , TEL          VARCHAR2 (   20 )                                       /* 100 電話番号     */
 , MAILAD       VARCHAR2 (  100 )                                       /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        VARCHAR2 (  200 )                                       /* 120 ﾌｧｲﾙ1        */
 , FILE2        VARCHAR2 (  200 )                                       /* 130 ﾌｧｲﾙ2        */
 , FILE3        VARCHAR2 (  200 )                                       /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     VARCHAR2 (  200 )                                       /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          VARCHAR2 (  200 )                                       /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE81S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE81T00 
  BEFORE INSERT ON GE81
  FOR EACH ROW 
  BEGIN 
    SELECT GE81S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
